
package Paws::DS::RestoreFromSnapshotResult;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::DS::RestoreFromSnapshotResult

=head1 ATTRIBUTES



=cut

1;